__search_path__ = __internal__.get("searchPath");
__loaded_scripts__ = {};
function cleanPath(path) {
	return path.replace("/", java.io.File.separator).replace("\\", java.io.File.separator);
}
function loadScript(filename) {
	filename = cleanPath(filename);
	if (filename.indexOf(".." + java.io.File.separator) >= 0) {
		throw "IllegalFilenameException: " + filename + " : you can't move up the script path in a filename";
	}
	if (typeof __loaded_scripts__[filename] != "undefined") {
		return; // we've already loaded it
	}
	
	// look up the search path to find the absolute file path
	var file = null;
	for (var i = 0; i < __search_path__.length; i++) {
		var pathElement = __search_path__[i];
		var file = new java.io.File(pathElement + filename);
		if (file.exists()) {
			break;
		}
	}
	if (! file.exists()) {
		throw "UnknownScriptException: " + filename;
	}
	__loaded_scripts__[filename] = true;
	
	// ensure we've got a compiled version of the script
	// this caching must match that in rhino.cfc's runScript method
	var canonPath = file.getCanonicalPath();
	if (! __internal__.get("scriptCache").containsKey(canonPath)
			|| __internal__.get("scriptCache").get(canonPath).get("timestamp").getTime() < file.lastModified()) {
		if (typeof System != "undefined" && System.log) {
			System.log("loading " + canonPath + " from disk");
		}
		var reader = new java.io.BufferedReader(new java.io.FileReader(file));
		var s = new java.util.HashMap();
		s.put("timestamp", new java.util.Date());
		s.put("script", __internal__.get("context").compileReader(
				reader,
				canonPath,
				1,
				null
			)
		);
		reader.close();
		__internal__.get("scriptCache").put(canonPath, s);
	} else {
		if (typeof System != "undefined"  && System.log) {
			System.log("loading " + filename + " from cache");
		}
	}
	
	// run it (through some reflection acrobatics)
	var method = java.lang.Class.forName("org.mozilla.javascript.Script").getMethod(
		"exec",
		Packages.org.mozilla.javascript.Context,
		Packages.org.mozilla.javascript.Scriptable
	);
	method.invoke(
		__internal__.get("scriptCache").get(canonPath).get("script"),
		__internal__.get("context"),
		__internal__.get("global_scope")
	);
}

// set up a couple aliases
javax = Packages.javax;
coldfusion = Packages.coldfusion;

// load the core stuff
loadScript("core/prototype.js");
loadScript("core/System.js");
loadScript("core/Util.js");
loadScript("sql/Query.js");
loadScript("sql/QueryParam.js");

// run the actual script
loadScript(__internal__.get("scriptToRun"));